@@ -32,29 +32,42 @@
 
 static bool pciDetectDriver(FFGPUResult* gpu, FFstrbuf* pciDir, FFstrbuf* buffer, FF_MAYBE_UNUSED const char* drmKey)
 {
+    uint32_t pciDirLength = pciDir->length;
     ffStrbufAppendS(pciDir, "/driver");
     char pathBuf[PATH_MAX];
     ssize_t resultLength = readlink(pciDir->chars, pathBuf, sizeof(pathBuf));
-    if(resultLength > 0)
-    {
-        const char* slash = memrchr(pathBuf, '/', (size_t) resultLength);
-        if (slash)
-        {
-            slash++;
-            ffStrbufSetNS(&gpu->driver, (uint32_t) (resultLength - (slash - pathBuf)), slash);
-        }
+    if(resultLength <= 0) return false;
 
+    const char* slash = memrchr(pathBuf, '/', (size_t) resultLength);
+    if (slash)
+    {
+        slash++;
+        ffStrbufSetNS(&gpu->driver, (uint32_t) (resultLength - (slash - pathBuf)), slash);
+    }
+
+    if (instance.config.general.detectVersion)
+    {
         ffStrbufAppendS(pciDir, "/module/version");
         if (ffReadFileBuffer(pciDir->chars, buffer))
         {
             ffStrbufTrimRightSpace(buffer);
             ffStrbufAppendC(&gpu->driver, ' ');
             ffStrbufAppend(&gpu->driver, buffer);
-            return true;
+        }
+        else if (ffStrbufEqualS(&gpu->driver, "zx"))
+        {
+            ffStrbufSubstrBefore(pciDir, pciDirLength);
+            ffStrbufAppendS(pciDir, "/zx_info/driver_version");
+            if (ffReadFileBuffer(pciDir->chars, buffer))
+            {
+                ffStrbufTrimRightSpace(buffer);
+                ffStrbufAppendC(&gpu->driver, ' ');
+                ffStrbufAppend(&gpu->driver, buffer);
+            }
         }
     }
 
-    return false;
+    return true;
 }
 
 static void pciDetectAmdSpecific(const FFGPUOptions* options, FFGPUResult* gpu, FFstrbuf* pciDir, FFstrbuf* buffer)
@@ -120,19 +133,26 @@ static void pciDetectIntelSpecific(FFGPUResult* gpu, FFstrbuf* pciDir, FFstrbuf*
         ffStrbufSubstrAfter(&gpu->name, (uint32_t) strlen("Intel "));
     gpu->type = ffStrbufStartsWithIgnCaseS(&gpu->name, "Arc ") ? FF_GPU_TYPE_DISCRETE : FF_GPU_TYPE_INTEGRATED;
 
-    ffStrbufAppendS(pciDir, "/drm/");
-    FF_AUTO_CLOSE_DIR DIR* dirp = opendir(pciDir->chars);
-    if (!dirp) return;
-    struct dirent* entry;
-    while ((entry = readdir(dirp)) != NULL)
+    if (ffStrbufEqualS(&gpu->driver, "xe"))
     {
-        if (ffStrStartsWith(entry->d_name, "card")) break;
+        ffStrbufAppendS(pciDir, "/tile0/gt0/freq0/max_freq");
+    }
+    else
+    {
+        ffStrbufAppendS(pciDir, "/drm/");
+        FF_AUTO_CLOSE_DIR DIR* dirp = opendir(pciDir->chars);
+        if (!dirp) return;
+        struct dirent* entry;
+        while ((entry = readdir(dirp)) != NULL)
+        {
+            if (ffStrStartsWith(entry->d_name, "card")) break;
+        }
+        if (!entry) return;
+        ffStrbufAppendS(pciDir, entry->d_name);
+        ffStrbufAppendS(pciDir, "/gt_max_freq_mhz");
     }
-    if (!entry) return;
-    ffStrbufAppendS(pciDir, entry->d_name);
-    ffStrbufAppendS(pciDir, "/gt_max_freq_mhz");
     if (ffReadFileBuffer(pciDir->chars, buffer))
-        gpu->frequency = ffStrbufToDouble(buffer) / 1000.0;
+        gpu->frequency = (uint32_t) ffStrbufToUInt(buffer, 0);
 }
 
 static bool loadPciIds(FFstrbuf* pciids)
@@ -198,6 +218,7 @@ static const char* detectPci(const FFGPUOptions* options, FFlist* gpus, FFstrbuf
         if (!ffStrbufStartsWithC(buffer, '1'))
             return "GPU disabled";
     }
+    ffStrbufSubstrBefore(deviceDir, drmDirPathLength);
 
     FFGPUResult* gpu = (FFGPUResult*)ffListAdd(gpus);
     ffStrbufInitStatic(&gpu->vendor, ffGetGPUVendorString((uint16_t) vendorId));
@@ -325,7 +346,7 @@ FF_MAYBE_UNUSED static const char* detectAsahi(FFlist* gpus, FFstrbuf* buffer, F
         }) >= 0)
         {
             gpu->coreCount = (int) paramsGlobal.num_cores_total_active;
-            gpu->frequency = paramsGlobal.max_frequency_khz / 1e6;
+            gpu->frequency = paramsGlobal.max_frequency_khz / 1000;
             gpu->deviceId = paramsGlobal.chip_id;
         }
     }
